@@ -6,7 +6,7 @@ from .bus_transciever import (AddressedCommand, AddressedMessage, BadFrame,
                              DirectArcPowerCommand, NakMessage,
                              NumericResponseMessage, SpecialCommand)
 
-from .gear import DaliGear, GearType
+from .gear import DaliGear, GearType, DaliGearGroup
 from .transciever_scanner import scan_for_dali_transcievers
 from .types import (DaliCommandCode, DaliException, FramingException,
                     SearchAddressClashException, SpecialCommandCode)
